==> snipe-it-6.3.0.zip: snipe-it-6.3.0/resources/lang/hr-HR/mail.php <==
<?php

return [
    'acceptance_asset_accepted' => 'A user has accepted an item',
    'acceptance_asset_declined' => 'A user has declined an item',
    'a_user_canceled' => 'Korisnik je otkazao zahtjev za stavkom na web mjestu',
    'a_user_requested' => 'Korisnik je zatražio stavku na web mjestu',
    'accessory_name' => 'Naziv dodatne opreme:',
    'additional_notes' => 'Dodatne napomene:',
    'admin_has_created' => 'Administrator vam je stvorio račun na: web stranici.',
    'asset' => 'Imovina:',
    'asset_name' => 'Naziv imovine:',
    'asset_requested' => 'Traženo sredstvo',
    'asset_tag' => 'Oznaka imovine',
    'assigned_to' => 'Dodijeljena',
    'best_regards' => 'Lijepi Pozdrav,',
    'canceled' => 'otkazano:',
    'checkin_date' => 'Datum prijave:',
    'checkout_date' => 'Datum kupnje:',
    'click_to_confirm' => 'Kliknite na sljedeću vezu kako biste potvrdili svoj: web račun:',
    'click_on_the_link_accessory' => 'Kliknite vezu pri dnu da biste potvrdili da ste primili dodatnu opremu.',
    'click_on_the_link_asset' => 'Kliknite vezu pri dnu kako biste potvrdili da ste primili sredstvo.',
    'Confirm_Asset_Checkin' => 'Asset checkin confirmation',
    'Confirm_Accessory_Checkin' => 'Accessory checkin confirmation',
    'Confirm_accessory_delivery' => 'Accessory delivery confirmation',
    'Confirm_license_delivery' => 'License delivery confirmation',
    'Confirm_asset_delivery' => 'Asset delivery confirmation',
    'Confirm_consumable_delivery' => 'Consumable delivery confirmation',
    'current_QTY' => 'Trenutna QTY',
    'Days' => 'dana',
    'days' => 'dana',
    'expecting_checkin_date' => 'Datum predviđenog provjere:',
    'expires' => 'istječe',
    'Expiring_Assets_Report' => 'Izvješće o isteku aktive.',
    'Expiring_Licenses_Report' => 'Istječe izvješće licenci.',
    'hello' => 'zdravo',
    'hi' => 'bok',
    'i_have_read' => 'Pročitao sam i prihvaćam uvjete korištenja i primio sam ovu stavku.',
    'item' => 'Artikal:',
    'Item_Request_Canceled' => 'Zahtjev za stavku je otkazan',
    'Item_Requested' => 'Potrebna stavka',
    'link_to_update_password' => 'Kliknite sljedeću vezu da biste ažurirali svoju: web lozinku:',
    'login_first_admin' => 'Prijavite se na svoju novu Snipe-IT instalaciju pomoću vjerodajnica u nastavku:',
    'login' => 'Prijaviti se:',
    'Low_Inventory_Report' => 'Izvješće o niskom oglasnom prostoru',
    'inventory_report' => 'Inventory Report',
    'min_QTY' => 'Min QTY',
    'name' => 'Ime',
    'new_item_checked' => 'Nova stavka je provjerena pod vašim imenom, detalji su u nastavku.',
    'password' => 'Lozinka:',
    'password_reset' => 'Ponovno postavljanje zaporke',

    'read_the_terms' => 'Pročitajte uvjete upotrebe u nastavku.',
    'read_the_terms_and_click' => 'Pročitajte uvjete upotrebe u nastavku i kliknite vezu pri dnu da biste potvrdili da ste pročitali i prihvatili uvjete upotrebe te ste dobili taj element.',
    'requested' => 'Traženi:',
    'reset_link' => 'Vaša lozinka resetiraj vezu',
    'reset_password' => 'Kliknite ovdje da biste poništili zaporku:',
    'serial' => 'Serijski',
    'supplier' => 'Dobavljač',
    'tag' => 'Označiti',
    'test_email' => 'Isprobajte e-poštu od Snipe-IT',
    'test_mail_text' => 'Ovo je test od Snipe-IT Asset Management sustava. Ako to dobijete, mail radi :)',
    'the_following_item' => 'Potvrđena je sljedeća stavka:',
    'low_inventory_alert' => 'Postoji :count stavka koja je ispod minimalnog iznosa zaliha ili će uskoro biti.|Postoje :count stavke koje su ispod minimalnog iznosa zaliha ili će uskoro biti.',
    'assets_warrantee_alert' => 'There is :count asset with a warranty expiring in the next :threshold days.|There are :count assets with warranties expiring in the next :threshold days.',
    'license_expiring_alert' => 'Postoji :count licenca koja istječe u naredna :threshold dana.|Postoje :count licence koje istječu u naredna :threshold dana.',
    'to_reset' => 'Da biste vratili svoju web-zaporku, ispunite ovaj obrazac:',
    'type' => 'Tip',
    'upcoming-audits' => 'There is :count asset that is coming up for audit within :threshold days.|There are :count assets that are coming up for audit within :threshold days.',
    'user' => 'Korisnik',
    'username' => 'Korisničko ime',
    'welcome' => 'Dobrodošli: ime',
    'welcome_to' => 'Dobrodošli na: web!',
    'your_credentials' => 'Vaše vjerodajnice za Snipe-IT',
    'Accessory_Checkin_Notification' => 'Accessory checked in',
    'Asset_Checkin_Notification' => 'Asset checked in',
    'Asset_Checkout_Notification' => 'Asset checked out',
    'License_Checkin_Notification' => 'License checked in',
    'Expected_Checkin_Report' => 'Expected asset checkin report',
    'Expected_Checkin_Notification' => 'Reminder: :name checkin deadline approaching',
    'Expected_Checkin_Date' => 'An asset checked out to you is due to be checked back in on :date',
    'your_assets' => 'View Your Assets',
    'rights_reserved' => 'All rights reserved.',
];

==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/hr-HR/mail.php <==
<?php

return [

    'Accessory_Checkin_Notification' => 'Accessory checked in',
    'Accessory_Checkout_Notification' => 'Accessory checked out',
    'Asset_Checkin_Notification' => 'Asset checked in',
    'Asset_Checkout_Notification' => 'Asset checked out',
    'Confirm_Accessory_Checkin' => 'Accessory checkin confirmation',
    'Confirm_Asset_Checkin' => 'Asset checkin confirmation',
    'Confirm_accessory_delivery' => 'Accessory delivery confirmation',
    'Confirm_asset_delivery' => 'Asset delivery confirmation',
    'Confirm_consumable_delivery' => 'Consumable delivery confirmation',
    'Confirm_license_delivery' => 'License delivery confirmation',
    'Consumable_checkout_notification' => 'Consumable checked out',
    'Days' => 'dana',
    'Expected_Checkin_Date' => 'An asset checked out to you is due to be checked back in on :date',
    'Expected_Checkin_Notification' => 'Reminder: :name checkin deadline approaching',
    'Expected_Checkin_Report' => 'Expected asset checkin report',
    'Expiring_Assets_Report' => 'Izvješće o isteku aktive.',
    'Expiring_Licenses_Report' => 'Istječe izvješće licenci.',
    'Item_Request_Canceled' => 'Zahtjev za stavku je otkazan',
    'Item_Requested' => 'Potrebna stavka',
    'License_Checkin_Notification' => 'License checked in',
    'License_Checkout_Notification' => 'License checked out',
    'Low_Inventory_Report' => 'Izvješće o niskom oglasnom prostoru',
    'a_user_canceled' => 'Korisnik je otkazao zahtjev za stavkom na web mjestu',
    'a_user_requested' => 'Korisnik je zatražio stavku na web mjestu',
    'acceptance_asset_accepted' => 'A user has accepted an item',
    'acceptance_asset_declined' => 'A user has declined an item',
    'accessory_name' => 'Naziv dodatne opreme:',
    'additional_notes' => 'Dodatne napomene:',
    'admin_has_created' => 'Administrator vam je stvorio račun na: web stranici.',
    'asset' => 'Imovina:',
    'asset_name' => 'Naziv imovine:',
    'asset_requested' => 'Traženo sredstvo',
    'asset_tag' => 'Oznaka imovine',
    'assets_warrantee_alert' => 'There is :count asset with a warranty expiring in the next :threshold days.|There are :count assets with warranties expiring in the next :threshold days.',
    'assigned_to' => 'Dodijeljena',
    'best_regards' => 'Lijepi Pozdrav,',
    'canceled' => 'otkazano:',
    'checkin_date' => 'Datum prijave:',
    'checkout_date' => 'Datum kupnje:',
    'checkedout_from' => 'Checked out from',
    'checkedin_from'  => 'Checked in from',
    'checked_into' => 'Checked into',
    'click_on_the_link_accessory' => 'Kliknite vezu pri dnu da biste potvrdili da ste primili dodatnu opremu.',
    'click_on_the_link_asset' => 'Kliknite vezu pri dnu kako biste potvrdili da ste primili sredstvo.',
    'click_to_confirm' => 'Kliknite na sljedeću vezu kako biste potvrdili svoj: web račun:',
    'current_QTY' => 'Trenutna QTY',
    'days' => 'dana',
    'expecting_checkin_date' => 'Datum predviđenog provjere:',
    'expires' => 'istječe',
    'hello' => 'zdravo',
    'hi' => 'bok',
    'i_have_read' => 'Pročitao sam i prihvaćam uvjete korištenja i primio sam ovu stavku.',
    'inventory_report' => 'Inventory Report',
    'item' => 'Artikal:',
    'item_checked_reminder' => 'This is a reminder that you currently have :count items checked out to you that you have not accepted or declined. Please click the link below to confirm your decision.',
    'license_expiring_alert' => 'Postoji :count licenca koja istječe u naredna :threshold dana.|Postoje :count licence koje istječu u naredna :threshold dana.',
    'link_to_update_password' => 'Kliknite sljedeću vezu da biste ažurirali svoju: web lozinku:',
    'login' => 'Prijaviti se:',
    'login_first_admin' => 'Prijavite se na svoju novu Snipe-IT instalaciju pomoću vjerodajnica u nastavku:',
    'low_inventory_alert' => 'Postoji :count stavka koja je ispod minimalnog iznosa zaliha ili će uskoro biti.|Postoje :count stavke koje su ispod minimalnog iznosa zaliha ili će uskoro biti.',
    'min_QTY' => 'Min QTY',
    'name' => 'Ime',
    'new_item_checked' => 'Nova stavka je provjerena pod vašim imenom, detalji su u nastavku.',
    'notes' => 'Bilješke',
    'password' => 'Lozinka:',
    'password_reset' => 'Ponovno postavljanje zaporke',
    'read_the_terms' => 'Pročitajte uvjete upotrebe u nastavku.',
    'read_the_terms_and_click' => 'Molimo pročitajte uvjete korištenja u nastavku i kliknite na poveznicu na dnu kako biste potvrdili da ste pročitali i da se slažete s uvjetima korištenja te da ste primili imovinu.',
    'requested' => 'Traženi:',
    'reset_link' => 'Vaša lozinka resetiraj vezu',
    'reset_password' => 'Kliknite ovdje da biste poništili zaporku:',
    'rights_reserved' => 'All rights reserved.',
    'serial' => 'Serijski',
    'snipe_webhook_test' => 'Snipe-IT Integration Test',
    'snipe_webhook_summary' => 'Snipe-IT Integration Test Summary',
    'supplier' => 'Dobavljač',
    'tag' => 'Označiti',
    'test_email' => 'Isprobajte e-poštu od Snipe-IT',
    'test_mail_text' => 'Ovo je test od Snipe-IT Asset Management sustava. Ako to dobijete, mail radi :)',
    'the_following_item' => 'Potvrđena je sljedeća stavka:',
    'to_reset' => 'Da biste vratili svoju web-zaporku, ispunite ovaj obrazac:',
    'type' => 'Tip',
    'upcoming-audits' => 'There is :count asset that is coming up for audit within :threshold days.|There are :count assets that are coming up for audit within :threshold days.',
    'user' => 'Korisnik',
    'username' => 'Korisničko ime',
    'unaccepted_asset_reminder' => 'You have Unaccepted Assets.',
    'welcome' => 'Dobrodošli: ime',
    'welcome_to' => 'Dobrodošli na: web!',
    'your_assets' => 'View Your Assets',
    'your_credentials' => 'Vaše vjerodajnice za Snipe-IT',
    'mail_sent' => 'Mail sent successfully!',
];
